#!/bin/sh
 
. alt-test-functions
. shell-ini-config

# Test desktop file localization (language is defined in LC_MESSAGES environment variable)
test_desktop_l10n()
{
	desktop="${1:-UNKNOWNFILE}"
	lang="$(locale | sed -n 's/^LC_MESSAGES=\"\([^.]\+\)\..*$/\1/p')"
	explanation="${2:-Desktop file $desktop is not localized in $lang}"
	name=""
	generic_name=""
	comment=""
	details=""
	
	if [ ! -e "${desktop}" ] ; then
		ok $_FAILURE "Missing file ${desktop}"
		return $_FAILURE
	fi
	
	# Test for hidden and non-displayed item
	test "$(ini_config_get "$desktop" 'Desktop Entry' Hidden)" = "true" && return $_SUCCESS
	test "$(ini_config_get "$desktop" 'Desktop Entry' NoDisplay)" = "true" && return $_SUCCESS
	has_comment="$(ini_config_get "$desktop" 'Desktop Entry' Comment)"

	# Check for long and short form of language
	for l in "$lang" "${lang%%_*}"; do
		# Check for localized Name
		v="$(sed -n "s/^[\t ]*Name\[$l\] *= *\(.*\)/\1/p" "$desktop")"
		test -n "$v" && name="$v"
		
		# Check for localized GenericName
		v="$(sed -n "s/^[\t ]*GenericName\[$l\] *= *\(.*\)/\1/p" "$desktop")"
		test -n "$v" && generic_name="$v"
		
		# Check for localized Comment (if Comment exists)
		v="$(sed -n "s/^[\t ]*Comment\[$l\] *= *\(.*\)/\1/p" "$desktop")"
		test -n "$v" && comment="$v"
	done

	# If localized GenericName is empty localized Name can be used
	test -n "$name" -a -z "$generic_name" && generic_name="$name"
	
	# Check for localized Comment only if there is original Comment in desktop file
	test -z "$has_comment" && comment="x"
	
	# Return result
	if [ -n "$generic_name" -a -n "$comment" ] ; then
		ok $_SUCCESS "Desktop file $desktop is completely localized in $lang"
		return $_SUCCESS
	else 
		test -z "$generic_name" -a -z "$comment" && details=": no localized Name or GenericName and Comment"
		test -z "$generic_name" -a -n "$comment" && details=": no localized Name or GenericName"
		test -n "$generic_name" -a -z "$comment" && details=": no localized Comment"
		ok $_FAILURE "$explanation$details"
		return $_FAILURE
	fi
}


# Check desktop file localization in current locale
out="$(mktemp)"
find /usr/share/applications -name \*.desktop > $out
while read -r desktop_file; do
	test_desktop_l10n "$desktop_file"
done < $out
rm -f $out

test_end
