#!/bin/sh

. alt-test-functions

# Test Mozilla extensions
uidtbl='
{ec8030f7-c20a-464f-9b0e-13a3a9e97384} Firefox 24.1.0
{3550f703-e582-4d05-9a08-453d09bdfdc6} Thunderbird 24.1.0
{92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a} Seamonkey 2.21
'

uid3tbl='
toolkit@mozilla.org Firefox 24.1.0
'

uid2name() {
    local uid="`printf %s "$1" |tr '[A-Z]' '[a-z]'`"
    printf '%s\n' "$uidtbl$uid3tbl" |
        grep "^$uid " |
        cut -d ' ' -f2-3
}

get_extension_versions() {
	f="$1"
	cat $f | egrep ':(id|maxVersion)[=>]' | sed -e 's/^[^:]*:\([^>=]*\)[=>]\("\)\?\([^<"]*\)\("\)\?.*$/\1 \3/' | parse_rdf
}

parse_rdf() {
	app=""
	while read name val; do
		if test "$name" = "id"; then
			app="$(uid2name "$val")"
			test -n "$app" && echo -en "$app\t"
		fi
		if test "$name" = "maxVersion" -a -n "$app"; then
			app=""
			printf '%s\n' "$val"
		fi
	done
}

# Get extension list
out="$(mktemp)"
find /usr/share/mozilla/extensions/ -maxdepth 3 -a -name install.rdf > $out
while read -r install_file; do
	# Get extension UID and package name
	ext="$(echo "$install_file" | sed -e 's,^/usr/share/mozilla/extensions/\([^/]*\)/.*$,\1,')"
	pkg="$(rpm -qf "$install_file" --qf "%{name}-%{version}-%{release}")"

	versions="$(mktemp)"
	get_extension_versions "$install_file" > $versions
	
	while read -r name cur_ver max_ver; do
		if [ $(rpmvercmp "${max_ver/\*/z}" "${cur_ver/\*/z}") -ge 0 ] ; then
			ok $_SUCCESS "Mozilla extension $ext from $pkg is sutable for $name $cur_ver (max version is $max_ver)"
		else
			ok $_FAILURE "Mozilla extension $ext from $pkg is not supported for $name $cur_ver (max version is $max_ver)"
		fi
	done < $versions
	
	rm -f $versions
done < $out
rm -f $out

test_end
